@@ -42,7 +42,9 @@ Peeter
 #include <unistd.h>
 #include <fcntl.h>
 #include <elf.h>
-#include <link.h>
+#if defined(HAVE_LINK_H)
+#  include <link.h>
+#endif /* HAVE_LINK_H */
 #include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
